========================
API Documentation
========================

This page contains auto-generated documentation of the major modules, functions, and classes of ``qp``. 


.. toctree::
    :maxdepth: 2

    core
    parameterizations
    utils
    plotting
    metrics